@@ -2,14 +2,18 @@
 
 from flask import request, redirect
 
+YEAR_IN_SECS = 31536000
+
+
 class SSLify(object):
     """Secures your Flask App."""
 
-    def __init__(self, app, age=31536000, subdomains=False):
+    def __init__(self, app, age=YEAR_IN_SECS, subdomains=False, permanent=False):
         if app is not None:
             self.app = app
             self.hsts_age = age
             self.hsts_include_subdomains = subdomains
+            self.permanent = permanent
 
             self.init_app(self.app)
         else:
@@ -40,15 +44,16 @@ class SSLify(object):
         ]
 
         if not any(criteria):
-            url = request.url.replace('http://', 'https://')
-            r = redirect(url)
+            if request.url.startswith('http://'):
+                url = request.url.replace('http://', 'https://', 1)
+                code = 302
+                if self.permanent:
+                    code = 301
+                r = redirect(url, code=code)
 
-            return r
+                return r
 
     def set_hsts_header(self, response):
         """Adds HSTS header to each response."""
         response.headers.setdefault('Strict-Transport-Security', self.hsts_header)
         return response
-
-
-
